@@ -108,11 +108,20 @@ sub form {
                 type => 'text',
                 is => 'varchar',
             },
+            {
+                options => [
+                    { label => 'Cell', value => 'cell' },
+                    { label => 'Home', value => 'home' },
+                ],
+                name => 'phone_type',
+                label => 'Phone Type',
+                type => 'select',
+                is => 'varchar',
+            },
         ],
     };
 } # END form
 
-
 1;
 
 =head1 NAME
@@ -123,16 +132,13 @@ Contact::GEN::Number - generated support module for Contact::Number
 
 In Contact::Number:
 
-    use Contact::GEN::Number qw(
-        do_main
-        form
-    );
+    use base 'Contact::GEN::Number';
 
 =head1 DESCRIPTION
 
 This module was generated by bigtop and IS subject to regeneration.
 Use it in Contact::Number to provide the methods below.
-They are exported by default.
+Feel free to override them.
 
 =head1 METHODS
 
